from airflow import models
from airflow.operators.bash_operator import BashOperator
from datetime import datetime, timedelta
    
default_args = {
    'owner': 'airflow',
    'depends_on_past': False,
    'start_date': datetime(2021, 5, 27),
    'email': ['airflow@airflow.com'],
    'email_on_failure': False,
    'email_on_retry': False,
    'retries': 1,
    'retry_delay': timedelta(minutes=5)
}

with models.DAG(dag_id='test', description='First DAG', schedule_interval = '55 15 * * *', default_args=default_args) as dag:
    t1 = BashOperator(
        task_id='print_date', 
        bash_command='date',
        dag=dag
    )

    t2 = BashOperator(
        task_id='sleep',
        bash_command='sleep 5',
        retries=3,
        dag=dag
    )

    templated_command="""
    {% for i in range(5) %}
        echo "{#{ ds }#}"
        echo "{#{ macros.ds_add(ds, 7)}#}"
        echo "{#{ params.my_param }#}"
    {% endfor %}
    """
    
    t3 = BashOperator(
        task_id='templated',
        bash_command=templated_command,
        params={'my_param': 'Parameter I passed in'},
        dag=dag
    )
        
    t2.set_upstream(t1)
    t3.set_upstream(t1)
